==> kwidgetsaddons-4.99.0.zip: kwidgetsaddons-4.99.0/tests/kpagewidgettest.h <==
/*
    This file is part of the KDE Libraries

    Copyright (C) 2006 Tobias Koenig (tokoe@kde.org)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB. If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef KPAGEWIDGETTEST_H
#define KPAGEWIDGETTEST_H

#include <QWidget>

#include "kpagewidget.h"

class KPageWidgetTest : public QWidget
{
    Q_OBJECT

public:
    KPageWidgetTest(QWidget *parent = 0);
    ~KPageWidgetTest();

private Q_SLOTS:
    void setAutoFace();
    void setPlainFace();
    void setListFace();
    void setTreeFace();
    void setTabbedFace();

    void addPage();
    void addSubPage();
    void insertPage();
    void deletePage();

    void currentPageChanged(KPageWidgetItem *, KPageWidgetItem *);
    void pageToggled(KPageWidgetItem *, bool);

private:
    KPageWidget *mWidget;
};

#endif

==> kwidgetsaddons-5.66.0.zip: kwidgetsaddons-5.66.0/tests/kpagewidgettest.h <==
/*
    This file is part of the KDE Libraries

    Copyright (C) 2006 Tobias Koenig (tokoe@kde.org)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB. If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef KPAGEWIDGETTEST_H
#define KPAGEWIDGETTEST_H

#include <QWidget>

#include "kpagewidget.h"

class KPageWidgetTest : public QWidget
{
    Q_OBJECT

public:
    KPageWidgetTest(QWidget *parent = nullptr);
    ~KPageWidgetTest();

private Q_SLOTS:
    void setAutoFace();
    void setPlainFace();
    void setListFace();
    void setTreeFace();
    void setTabbedFace();

    void addPage();
    void addSubPage();
    void insertPage();
    void deletePage();

    void currentPageChanged(KPageWidgetItem *, KPageWidgetItem *);
    void pageToggled(KPageWidgetItem *, bool);

private:
    KPageWidget *mWidget;
};

#endif
